@@ -524,6 +524,73 @@ void matcentrage (double **A, double *poili, char *typ)
         return;
     }
 }
+/***********************************************************************/
+ void matcentragehi (double **tab, double *poili, int *index, int *assign)
+{
+/*centrage d'un tableau de hill smith
+tab tableau avec quantitatives et qualitatives disjonctifs complets
+poili vecteur poids lignes
+index indique si chaque variables est quali (1) ou quanti (2)
+assign vecteur entier qui donne l'index de la variable pour chaque colonne
+*/
+
+    int l1,c1,i,j,nquant=0,nqual=0,jqual=1,jquant=1;
+    double **tabqual, **tabquant;
+    l1 = tab[0][0];
+    c1 = tab[1][0];
+    for(j=1;j<=c1;j++){
+	if(index[assign[j]]==1){
+		nqual=nqual+1;
+	}
+	else if (index[assign[j]]==2){
+		nquant=nquant+1;
+	}
+    }
+
+    taballoc(&tabqual,l1,nqual);
+    taballoc(&tabquant,l1,nquant);
+
+    for (j=1;j<=c1;j++){
+        if (index[assign[j]]==1) {
+            for (i=1; i<=l1;i++) {
+                tabqual[i][jqual]=tab[i][j];
+		
+                }
+	    jqual=jqual+1;
+        } else if (index[assign[j]]==2){
+            for (i=1; i<=l1;i++) {
+                tabquant[i][jquant]=tab[i][j];
+		
+                }
+	    jquant=jquant+1;
+            }
+     }   
+        
+    
+    matmodifcm (tabqual, poili);
+    matmodifcn (tabquant, poili);
+    jqual=1;
+    jquant=1;
+    
+    for (j=1;j<=c1;j++) {
+	if (index[assign[j]]==1) {
+        	for (i=1;i<=l1;i++) {
+			tab[i][j] = tabqual[i][jqual];
+            	}
+	jqual=jqual+1;	
+        }
+	else if (index[assign[j]]==2) {
+        	for (i=1;i<=l1;i++) {
+			tab[i][j] = tabquant[i][jquant];
+            	}
+	jquant=jquant+1;	
+        }
+    }
+    freetab(tabqual);
+    freetab(tabquant);
+    return;
+}
+
 /***********************************************************************/
 void matmodifcm (double **tab, double *poili)
 /*--------------------------------------------------
@@ -1145,3 +1212,197 @@ void vecpermut (double *A, int *num, double *B)
         B[i] = A[k];
     }
 }
+
+
+/***********************************************************************/
+
+/*=====================================================================*/
+/*                     MODELES DE PERMUTATION                          */
+/*=====================================================================*/
+
+
+void permutmodel1(double **X1,double **X1permute,int *ligL,int *colL)
+{
+
+/* permute each column independently */
+  
+  /* Declaration des variables locales */
+  double  *a;
+  int i,j,k,ligL1,colL1;
+  ligL1=*ligL;
+  colL1=*colL;
+  
+  /* Allocation memoire pour les variables C locales */
+  vecalloc(&a, ligL1);
+  
+  /* Permutation de la matrice */
+  for(j=1;j<=colL1;j++)
+    {
+      for(i=1;i<=ligL1;i++)
+        {
+	  a[i]=X1[i][j];
+	  
+        }
+      
+      aleapermutvec (a);
+      
+      /* Construction de la matrice X1permute*/
+      for(k=1;k<=ligL1;k++)
+        {   
+	  X1permute[k][j]=a[k];
+	  
+        }
+      
+    }
+  
+  freevec(a);
+}
+
+
+void permutmodel3(double **X1,double **X1permute,int *ligL,int *colL)
+{
+/*****************************************************************/
+/* Fonction qui permute selon le model 3 de la methode du 4e coin*/
+/*****************************************************************/
+/* permutation a l"interieur de chaque ligne (site) independamement */
+    /* Declaration des variables locales */
+    double  *a;
+    int i,j,k,ligL1,colL1;
+    ligL1=*ligL;
+    colL1=*colL;
+    /* Allocation memoire pour les variables C locales */
+    vecalloc(&a, colL1);
+    
+    /* Permutation de la matrice */
+    for(i=1;i<=ligL1;i++)
+    {
+        for(j=1;j<=colL1;j++)
+        {
+            a[j]=X1[i][j];
+        }
+        aleapermutvec (a);
+        
+    /* Construction de la matrice contenant les vecteurs permuts */
+        for (k=1; k<=colL1; k++)
+        {
+            X1permute[i][k]=a[k];       
+        }
+    }
+    freevec(a);
+}
+
+
+/*=====================================================================*/
+
+void permutmodel4(double **X1, double **X1permute, int *ligL, int *colL)
+{
+/*****************************************************************/
+/* Fonction qui permute selon le model 4 de la methode du 4e coin*/
+/*****************************************************************/
+/*  permute des colonnes */
+
+    /* Declaration des variables locales */
+    int i,j,ligL1,colL1;
+    ligL1=*ligL;
+    colL1=*colL;
+    double **X1transposee;
+    taballoc(&X1transposee,colL1,ligL1);
+    
+    /* Transposee de X1 */
+    
+    for (i=1; i<=ligL1; i++)
+    {
+        for (j=1; j<=colL1; j++)
+        {
+            X1transposee[j][i]=X1[i][j];
+        }
+    }
+    
+    aleapermutmat (X1transposee);
+        
+        
+    //Retransposons la matrice
+        
+        for (j=1; j<=colL1; j++)
+        {
+            for (i=1; i<=ligL1; i++)
+            {
+                X1permute[i][j]=X1transposee[j][i];
+            }
+        }
+    freetab(X1transposee);
+}
+
+/*=====================================================================*/
+
+void permutmodel2(double **X1, double **X1permute, int *ligL, int *colL)
+{
+/*****************************************************************/
+/* Fonction qui permute selon le model 2 de la methode du 4e coin*/
+/*****************************************************************/
+/* permute des lignes */
+    int i,j,ligL1,colL1;
+    ligL1=*ligL;
+    colL1=*colL;
+
+    for (j=1; j<=colL1; j++)
+        {
+            for (i=1; i<=ligL1; i++)
+            {
+                X1permute[i][j]=X1[i][j];
+            }
+        }
+
+    aleapermutmat (X1permute);
+}
+
+/*=====================================================================*/
+
+void permutmodel5(double **X1, double **X1permute, int *ligL, int *colL)
+{
+/*****************************************************************/
+/* Fonction qui permute selon le model 5 (new)*/
+/*****************************************************************/
+/* permute des lignes puis des colonnes*/
+
+    int i,j,ligL1,colL1;
+    double **X1transposee;
+    ligL1=*ligL;
+    colL1=*colL;
+    
+    taballoc(&X1transposee,colL1,ligL1);
+    for (j=1; j<=colL1; j++)
+        {
+            for (i=1; i<=ligL1; i++)
+            {
+                X1permute[i][j]=X1[i][j];
+            }
+        }
+
+    aleapermutmat (X1permute); /* perm lignes */
+    
+    /* Transposee de X1permute */
+    
+    for (i=1; i<=ligL1; i++)
+    {
+        for (j=1; j<=colL1; j++)
+        {
+            X1transposee[j][i]=X1permute[i][j];
+        }
+    }
+    
+    aleapermutmat (X1transposee); /* perm colonnes */
+        
+        
+    //Retransposons la matrice
+        
+        for (j=1; j<=colL1; j++)
+        {
+            for (i=1; i<=ligL1; i++)
+            {
+                X1permute[i][j]=X1transposee[j][i];
+            }
+        }
+    freetab(X1transposee);
+
+}
